' === Count2Digits3Tasks.bas ===================================
'
' Program runs on a 20M2 processor, and uses an LDD-N514RI-RA
' 2-digit, 7-segment LED display. The digits are multiplexed
' by two transistors (a 2N3906 [PNP], and a 2N3904 [NPN)],
' which are both connected to the A.0 (pseudo) output pin.

' The program uses three parallel tasks to count from 00 to 99,
' and to blink an LED on pin C.0 in time with the count.
	
' === Directives ====
  #com 6                 'specify com port
  #picaxe 20M2           'specify PICAXE processor
  #no_data               'save time downloading
  #terminal off          'disable the terminal window

' === Variables =====
  symbol   dig01 = b0    'one's digit of the count
  symbol   dig10 = b1    'ten's digit of the count
  symbol  segs01 = b2    'stores segment pattern for one's digit
  symbol  segs10 = b3    'stores segment pattern for ten's digit
  symbol lastSec = b4    'used in Task 2 to delay one second 

' === Begin Main Program =======================================
start0:                  'Task = update segment values
dirsB= %11111111         'two-digit LED display on portB
dirsC= %10111111         'pin C.6 is fixed as an input

do
  if time > 99 then      'avoid overflow in the time variable
    time = 0
  endif
  
  dig01 = time // 10     'get the one's digit 
  lookup dig01,(63,6,91,79,102,109,125,7,127,111),segs01
  
  dig10 = time /  10     'get the ten's digit  
  lookup dig10,(63,6,91,79,102,109,125,7,127,111),segs10
loop

start1:                  'Task = multiplex the display
do
  pinsB = 0              'blank the display to avoid ghosting
  low A.0                'set up for one's digit
  pinsB = segs01         'display one's segments
  low A.0                'use in place of pause or pauseus
  low A.0                'to balance digit brightness
  pinsB = 0              'blank the display to avoid ghosting 
  high A.0               'set up for ten's digit
  pinsB = segs10         'display ten's segments
loop

start2:                  'Task = blink LED on pin C.0
do
  lastSec = time         'update lastSec
  high C.0               'briefly light LED
  pause 20
  low C.0                'then turn it off
  gosub waitAsec         'for remainder of one second
loop

waitAsec:                'delay for remainder of one second
  if lastSec = time then waitAsec
  return